Sampling Module
=================

.. automodule:: sampling
   :members:
   
   .. autosummary::
      
      sampling_circle_2d
      sampling_circle_3d
      sampling_parallelogram_2d
      sampling_alligned_parallelogram_2d
      sampling_parallelogram_3d
      sampling_parallelepiped_3d
      sampling_cuboid
      sampling_sphere
      sampling_np_array_elements
      sampling_pcd_points
      sampling_np_arrays_from_enumerable
